@@ -1,13 +1,13 @@
-'''
+"""
 The kernel main program.
-'''
+"""
 
 import argparse
 import importlib
 import os
-from pathlib import Path
 import signal
 import sys
+from pathlib import Path
 
 import uvloop
 
@@ -17,15 +17,15 @@ from .compat import asyncio_run_forever
 
 def parse_args(args=None):
     parser = argparse.ArgumentParser()
-    parser.add_argument('--debug', action='store_true', default=False)
-    parser.add_argument('lang', type=str, choices=lang_map.keys())
-    parser.add_argument('runtime_path', type=Path, nargs='?', default=None)
+    parser.add_argument("--debug", action="store_true", default=False)
+    parser.add_argument("lang", type=str, choices=lang_map.keys())
+    parser.add_argument("runtime_path", type=Path, nargs="?", default=None)
     return parser.parse_args(args)
 
 
 def main(args) -> None:
     cls_name = lang_map[args.lang]
-    imp_path, cls_name = cls_name.rsplit('.', 1)
+    imp_path, cls_name = cls_name.rsplit(".", 1)
     mod = importlib.import_module(imp_path)
     cls = getattr(mod, cls_name)
 
@@ -37,7 +37,7 @@ def main(args) -> None:
 
     # Replace stdin with a "null" file
     # (trying to read stdin will raise EOFError immediately afterwards.)
-    sys.stdin = open(os.devnull, 'r', encoding='latin1')
+    sys.stdin = open(os.devnull, "r", encoding="latin1")
     asyncio_run_forever(
         runner._init(args),
         runner._shutdown(),
